Documentation
¶
Overview ¶
Package dashboard collects Git repository data for the HTML dashboard.
Package dashboard collects Git repository data for the HTML dashboard.
Package dashboard collects Git repository data for the HTML dashboard.
Package dashboard provides data collection and output for the HTML dashboard.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Collect ¶
func Collect(opts CollectOptions) (model.DashboardData, error)
Collect gathers all repository data into a single DashboardData struct.
Types ¶
Click to show internal directories.
Click to hide internal directories.